@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
@@ -336,7 +336,7 @@ public:
 
     void addStateListener(StateListenerCb&& listener)
     {
-        std::lock_guard<std::recursive_mutex> lk {callMutex_};
+        std::lock_guard lk {callMutex_};
         stateChangedListeners_.emplace_back(std::move(listener));
     }
 
@@ -351,7 +351,7 @@ public:
     ///
     bool isSubcall() const
     {
-        std::lock_guard<std::recursive_mutex> lk {callMutex_};
+        std::lock_guard lk {callMutex_};
         return parent_ != nullptr;
     }
 
