@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
  *
@@ -129,8 +129,13 @@ getSignalHandlers()
 
         /* Conversation */
         exported_callback<libjami::ConversationSignal::ConversationLoaded>(),
+        exported_callback<libjami::ConversationSignal::SwarmLoaded>(),
         exported_callback<libjami::ConversationSignal::MessagesFound>(),
         exported_callback<libjami::ConversationSignal::MessageReceived>(),
+        exported_callback<libjami::ConversationSignal::SwarmMessageReceived>(),
+        exported_callback<libjami::ConversationSignal::SwarmMessageUpdated>(),
+        exported_callback<libjami::ConversationSignal::ReactionAdded>(),
+        exported_callback<libjami::ConversationSignal::ReactionRemoved>(),
         exported_callback<libjami::ConversationSignal::ConversationProfileUpdated>(),
         exported_callback<libjami::ConversationSignal::ConversationRequestReceived>(),
         exported_callback<libjami::ConversationSignal::ConversationRequestDeclined>(),
