@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Alexandre Lision <alexandre.lision@savoirfairelinux.com>
  *  Author: Vittorio Giovara <vittorio.giovara@savoirfairelinux.com>
@@ -27,7 +27,7 @@
 #include "config.h"
 #endif
 
-#include "certstore.h"
+#include <dhtnet/certstore.h>
 
 #include "fileutils.h"
 #include "logger.h"
@@ -220,11 +220,11 @@ const Matrix2D<TlsValidator::CheckValuesType, TlsValidator::CheckValues, bool>
         /* NUMBER   */ {{false, false, true, false, false, true}},
     }};
 
-TlsValidator::TlsValidator(const tls::CertificateStore& certStore, const std::vector<std::vector<uint8_t>>& crtChain)
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::vector<std::vector<uint8_t>>& crtChain)
     : TlsValidator(certStore, std::make_shared<dht::crypto::Certificate>(crtChain.begin(), crtChain.end()))
 {}
 
-TlsValidator::TlsValidator(const tls::CertificateStore& certStore,
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore,
                            const std::string& certificate,
                            const std::string& privatekey,
                            const std::string& privatekeyPasswd,
@@ -268,7 +268,7 @@ TlsValidator::TlsValidator(const tls::CertificateStore& certStore,
     }
 }
 
-TlsValidator::TlsValidator(const tls::CertificateStore& certStore, const std::vector<uint8_t>& certificate_raw)
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::vector<uint8_t>& certificate_raw)
     : certStore_(certStore)
 {
     try {
@@ -280,7 +280,7 @@ TlsValidator::TlsValidator(const tls::CertificateStore& certStore, const std::ve
     }
 }
 
-TlsValidator::TlsValidator(const tls::CertificateStore& certStore, const std::shared_ptr<dht::crypto::Certificate>& crt)
+TlsValidator::TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::shared_ptr<dht::crypto::Certificate>& crt)
     : certStore_(certStore)
     , certificateFound_(true)
 {
@@ -477,7 +477,7 @@ TlsValidator::compareToCa()
         JAMI_WARN("gnutls_x509_trust_list_add_cas failed: %s", gnutls_strerror(err));
 
     if (not caListPath_.empty()) {
-        if (fileutils::isDirectory(caListPath_))
+        if (std::filesystem::is_directory(caListPath_))
             gnutls_x509_trust_list_add_trust_dir(trust,
                                                  caListPath_.c_str(),
                                                  nullptr,
