@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
  *
@@ -21,9 +21,10 @@
 #pragma once
 
 #include "jami/datatransfer_interface.h"
-#include "connectivity/multiplexed_socket.h"
 #include "noncopyable.h"
 
+#include <dhtnet/multiplexed_socket.h>
+
 #include <fstream>
 #include <functional>
 #include <memory>
@@ -32,7 +33,7 @@
 
 namespace jami {
 
-libjami::DataTransferId generateUID();
+libjami::DataTransferId generateUID(std::mt19937_64& engine);
 
 class Stream;
 
@@ -58,13 +59,13 @@ typedef std::function<void()> OnFinishedCb;
 class FileInfo
 {
 public:
-    FileInfo(const std::shared_ptr<ChannelSocket>& channel,
+    FileInfo(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
              const std::string& fileId,
              const std::string& interactionId,
              const libjami::DataTransferInfo& info);
     virtual ~FileInfo() {}
     virtual void process() = 0;
-    std::shared_ptr<ChannelSocket> channel() const { return channel_; }
+    std::shared_ptr<dhtnet::ChannelSocket> channel() const { return channel_; }
     libjami::DataTransferInfo info() const { return info_; }
     virtual void cancel() = 0;
     void onFinished(std::function<void(uint32_t)>&& cb) { finishedCb_ = std::move(cb); }
@@ -75,14 +76,14 @@ protected:
     std::string fileId_ {};
     std::string interactionId_ {};
     libjami::DataTransferInfo info_ {};
-    std::shared_ptr<ChannelSocket> channel_ {};
+    std::shared_ptr<dhtnet::ChannelSocket> channel_ {};
     std::function<void(uint32_t)> finishedCb_ {};
 };
 
 class IncomingFile : public FileInfo, public std::enable_shared_from_this<IncomingFile>
 {
 public:
-    IncomingFile(const std::shared_ptr<ChannelSocket>& channel,
+    IncomingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                  const libjami::DataTransferInfo& info,
                  const std::string& fileId,
                  const std::string& interactionId,
@@ -96,6 +97,7 @@ private:
     {
         return std::static_pointer_cast<IncomingFile>(shared_from_this());
     }
+    std::mutex streamMtx_;
     std::ofstream stream_;
     std::string sha3Sum_ {};
 };
@@ -103,7 +105,7 @@ private:
 class OutgoingFile : public FileInfo
 {
 public:
-    OutgoingFile(const std::shared_ptr<ChannelSocket>& channel,
+    OutgoingFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                  const std::string& fileId,
                  const std::string& interactionId,
                  const libjami::DataTransferInfo& info,
@@ -122,7 +124,7 @@ private:
 class TransferManager : public std::enable_shared_from_this<TransferManager>
 {
 public:
-    TransferManager(const std::string& accountId, const std::string& to);
+    TransferManager(const std::string& accountId, const std::string& accountUri, const std::string& to, const std::mt19937_64& rand);
     ~TransferManager();
 
     /**
@@ -134,7 +136,7 @@ public:
      * @param start         start offset
      * @param end           end
      */
-    void transferFile(const std::shared_ptr<ChannelSocket>& channel,
+    void transferFile(const std::shared_ptr<dhtnet::ChannelSocket>& channel,
                       const std::string& fileId,
                       const std::string& interactionId,
                       const std::string& path,
@@ -181,13 +183,13 @@ public:
      * @param channel   Related channel
      */
     void onIncomingFileTransfer(const std::string& fileId,
-                                const std::shared_ptr<ChannelSocket>& channel);
+                                const std::shared_ptr<dhtnet::ChannelSocket>& channel);
 
     /**
      * Retrieve path of a file
      * @param id
      */
-    std::string path(const std::string& fileId) const;
+    std::filesystem::path path(const std::string& fileId) const;
 
     /**
      * Retrieve waiting files
@@ -195,13 +197,13 @@ public:
      */
     std::vector<WaitingRequest> waitingRequests() const;
     bool isWaiting(const std::string& fileId) const;
-    void onIncomingProfile(const std::shared_ptr<ChannelSocket>& channel, const std::string& sha3Sum = "");
+    void onIncomingProfile(const std::shared_ptr<dhtnet::ChannelSocket>& channel, const std::string& sha3Sum = "");
 
     /**
      * @param contactId     contact's id
      * @return where profile.vcf is stored
      */
-    std::string profilePath(const std::string& contactId) const;
+    std::filesystem::path profilePath(const std::string& contactId) const;
 
 private:
     std::weak_ptr<TransferManager> weak()
