@@ -1,23 +1,19 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
- *  Author: Rafaël Carré <rafael.carre@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -26,12 +22,9 @@
 #include "fileutils.h"
 #include "archiver.h"
 #include "compiler_intrinsics.h"
-#include <opendht/crypto.h>
+#include "base64.h"
 
-#ifdef RING_UWP
-#include <io.h> // for access and close
-#include "ring_signal.h"
-#endif
+#include <opendht/crypto.h>
 
 #ifdef __APPLE__
 #include <TargetConditionals.h>
@@ -76,7 +69,6 @@
 
 #include <sstream>
 #include <fstream>
-#include <filesystem>
 #include <iostream>
 #include <stdexcept>
 #include <limits>
@@ -127,28 +119,6 @@ winGetEnv(const wchar_t* name)
 namespace jami {
 namespace fileutils {
 
-// returns true if directory exists
-bool
-check_dir(const char* path, mode_t UNUSED dirmode, mode_t parentmode)
-{
-    DIR* dir = opendir(path);
-
-    if (!dir) { // doesn't exist
-        if (not recursive_mkdir(path, parentmode)) {
-            perror(path);
-            return false;
-        }
-#ifndef _WIN32
-        if (chmod(path, dirmode) < 0) {
-            JAMI_ERR("fileutils::check_dir(): chmod() failed on '%s', %s", path, strerror(errno));
-            return false;
-        }
-#endif
-    } else
-        closedir(dir);
-    return true;
-}
-
 std::string
 expand_path(const std::string& path)
 {
@@ -192,56 +162,6 @@ expand_path(const std::string& path)
 #endif
 }
 
-std::mutex&
-getFileLock(const std::string& path)
-{
-    static std::mutex fileLockLock {};
-    static std::map<std::string, std::mutex> fileLocks {};
-
-    std::lock_guard<std::mutex> l(fileLockLock);
-    return fileLocks[path];
-}
-
-bool
-isFile(const std::string& path, bool resolveSymlink)
-{
-    if (path.empty())
-        return false;
-#ifdef _WIN32
-    if (resolveSymlink) {
-        struct _stat64i32 s;
-        if (_wstat(jami::to_wstring(path).c_str(), &s) == 0)
-            return S_ISREG(s.st_mode);
-    } else {
-        DWORD attr = GetFileAttributes(jami::to_wstring(path).c_str());
-        if ((attr != INVALID_FILE_ATTRIBUTES) && !(attr & FILE_ATTRIBUTE_DIRECTORY)
-            && !(attr & FILE_ATTRIBUTE_REPARSE_POINT))
-            return true;
-    }
-#else
-    if (resolveSymlink) {
-        struct stat s;
-        if (stat(path.c_str(), &s) == 0)
-            return S_ISREG(s.st_mode);
-    } else {
-        struct stat s;
-        if (lstat(path.c_str(), &s) == 0)
-            return S_ISREG(s.st_mode);
-    }
-#endif
-
-    return false;
-}
-
-bool
-isDirectory(const std::string& path)
-{
-    struct stat s;
-    if (stat(path.c_str(), &s) == 0)
-        return s.st_mode & S_IFDIR;
-    return false;
-}
-
 bool
 isDirectoryWritable(const std::string& directory)
 {
@@ -249,87 +169,7 @@ isDirectoryWritable(const std::string& directory)
 }
 
 bool
-hasHardLink(const std::string& path)
-{
-#ifndef _WIN32
-    struct stat s;
-    if (lstat(path.c_str(), &s) == 0)
-        return s.st_nlink > 1;
-#endif
-    return false;
-}
-
-bool
-isSymLink(const std::string& path)
-{
-#ifndef _WIN32
-    struct stat s;
-    if (lstat(path.c_str(), &s) == 0)
-        return S_ISLNK(s.st_mode);
-#elif !defined(_MSC_VER)
-    DWORD attr = GetFileAttributes(jami::to_wstring(path).c_str());
-    if (attr & FILE_ATTRIBUTE_REPARSE_POINT)
-        return true;
-#endif
-    return false;
-}
-
-std::chrono::system_clock::time_point
-writeTime(const std::string& path)
-{
-#ifndef _WIN32
-    struct stat s;
-    auto ret = stat(path.c_str(), &s);
-    if (ret)
-        throw std::runtime_error("Can't check write time for: " + path);
-    return std::chrono::system_clock::from_time_t(s.st_mtime);
-#else
-#if RING_UWP
-    _CREATEFILE2_EXTENDED_PARAMETERS ext_params = {0};
-    ext_params.dwSize = sizeof(CREATEFILE2_EXTENDED_PARAMETERS);
-    ext_params.dwFileAttributes = FILE_ATTRIBUTE_NORMAL;
-    ext_params.dwFileFlags = FILE_FLAG_NO_BUFFERING;
-    ext_params.dwSecurityQosFlags = SECURITY_ANONYMOUS;
-    ext_params.lpSecurityAttributes = nullptr;
-    ext_params.hTemplateFile = nullptr;
-    HANDLE h = CreateFile2(jami::to_wstring(path).c_str(),
-                           GENERIC_READ,
-                           FILE_SHARE_READ,
-                           OPEN_EXISTING,
-                           &ext_params);
-#elif _WIN32
-    HANDLE h = CreateFileW(jami::to_wstring(path).c_str(),
-                           GENERIC_READ,
-                           FILE_SHARE_READ,
-                           nullptr,
-                           OPEN_EXISTING,
-                           FILE_ATTRIBUTE_NORMAL,
-                           nullptr);
-#endif
-    if (h == INVALID_HANDLE_VALUE)
-        throw std::runtime_error("Can't open: " + path);
-    FILETIME lastWriteTime;
-    if (!GetFileTime(h, nullptr, nullptr, &lastWriteTime))
-        throw std::runtime_error("Can't check write time for: " + path);
-    CloseHandle(h);
-    SYSTEMTIME sTime;
-    if (!FileTimeToSystemTime(&lastWriteTime, &sTime))
-        throw std::runtime_error("Can't check write time for: " + path);
-    struct tm tm
-    {};
-    tm.tm_year = sTime.wYear - 1900;
-    tm.tm_mon = sTime.wMonth - 1;
-    tm.tm_mday = sTime.wDay;
-    tm.tm_hour = sTime.wHour;
-    tm.tm_min = sTime.wMinute;
-    tm.tm_sec = sTime.wSecond;
-    tm.tm_isdst = -1;
-    return std::chrono::system_clock::from_time_t(mktime(&tm));
-#endif
-}
-
-bool
-createSymlink(const std::string& linkFile, const std::string& target)
+createSymlink(const std::filesystem::path& linkFile, const std::filesystem::path& target)
 {
     try {
         std::filesystem::create_symlink(target, linkFile);
@@ -341,7 +181,7 @@ createSymlink(const std::string& linkFile, const std::string& target)
 }
 
 bool
-createHardlink(const std::string& linkFile, const std::string& target)
+createHardlink(const std::filesystem::path& linkFile, const std::filesystem::path& target)
 {
     try {
         std::filesystem::create_hard_link(target, linkFile);
@@ -353,7 +193,7 @@ createHardlink(const std::string& linkFile, const std::string& target)
 }
 
 bool
-createFileLink(const std::string& linkFile, const std::string& target, bool hard)
+createFileLink(const std::filesystem::path& linkFile, const std::filesystem::path& target, bool hard)
 {
     if (not hard or not createHardlink(linkFile, target))
         return createSymlink(linkFile, target);
@@ -373,13 +213,9 @@ getFileExtension(std::string_view filename)
 }
 
 bool
-isPathRelative(const std::string& path)
+isPathRelative(const std::filesystem::path& path)
 {
-#ifndef _WIN32
-    return not path.empty() and not(path[0] == '/');
-#else
-    return not path.empty() and path.find(":") == std::string::npos;
-#endif
+    return not path.empty() and path.is_relative();
 }
 
 std::string
@@ -394,151 +230,84 @@ getCleanPath(const std::string& base, const std::string& path)
         return path;
 }
 
-std::string
-getFullPath(const std::string& base, const std::string& path)
+std::filesystem::path
+getFullPath(const std::filesystem::path& base, const std::filesystem::path& path)
 {
     bool isRelative {not base.empty() and isPathRelative(path)};
-    return isRelative ? base + DIR_SEPARATOR_STR + path : path;
+    return isRelative ? base / path : path;
 }
 
 std::vector<uint8_t>
-loadFile(const std::string& path, const std::string& default_dir)
+loadFile(const std::filesystem::path& path, const std::filesystem::path& default_dir)
 {
-    std::vector<uint8_t> buffer;
-    std::ifstream file = ifstream(getFullPath(default_dir, path), std::ios::binary);
-    if (!file)
-        throw std::runtime_error("Can't read file: " + path);
-    file.seekg(0, std::ios::end);
-    auto size = file.tellg();
-    if (size > std::numeric_limits<unsigned>::max())
-        throw std::runtime_error("File is too big: " + path);
-    buffer.resize(size);
-    file.seekg(0, std::ios::beg);
-    if (!file.read((char*) buffer.data(), size))
-        throw std::runtime_error("Can't load file: " + path);
-    return buffer;
+    return dhtnet::fileutils::loadFile(getFullPath(default_dir, path));
 }
 
 std::string
-loadTextFile(const std::string& path, const std::string& default_dir)
+loadTextFile(const std::filesystem::path& path, const std::filesystem::path& default_dir)
 {
     std::string buffer;
-    std::ifstream file = ifstream(getFullPath(default_dir, path));
+    std::ifstream file(getFullPath(default_dir, path));
     if (!file)
-        throw std::runtime_error("Can't read file: " + path);
+        throw std::runtime_error("Can't read file: " + path.string());
     file.seekg(0, std::ios::end);
     auto size = file.tellg();
     if (size > std::numeric_limits<unsigned>::max())
-        throw std::runtime_error("File is too big: " + path);
+        throw std::runtime_error("File is too big: " + path.string());
     buffer.resize(size);
     file.seekg(0, std::ios::beg);
     if (!file.read((char*) buffer.data(), size))
-        throw std::runtime_error("Can't load file: " + path);
+        throw std::runtime_error("Can't load file: " + path.string());
     return buffer;
 }
 
-bool
-copy(const std::string& src, const std::string& dest)
-{
-    return std::filesystem::copy_file(src, dest);
-}
-
 void
-saveFile(const std::string& path, const uint8_t* data, size_t data_size, mode_t UNUSED mode)
+saveFile(const std::filesystem::path& path,
+         const uint8_t* data,
+         size_t data_size,
+         mode_t UNUSED mode)
 {
-    std::ofstream file = fileutils::ofstream(path, std::ios::trunc | std::ios::binary);
+    std::ofstream file(path, std::ios::trunc | std::ios::binary);
     if (!file.is_open()) {
-        JAMI_ERR("Could not write data to %s", path.c_str());
+        JAMI_ERROR("Could not write data to {}", path);
         return;
     }
     file.write((char*) data, data_size);
 #ifndef _WIN32
+    file.close();
     if (chmod(path.c_str(), mode) < 0)
-        JAMI_WARN("fileutils::saveFile(): chmod() failed on '%s', %s",
-                  path.c_str(),
-                  strerror(errno));
+        JAMI_WARNING("fileutils::saveFile(): chmod() failed on {}, {}", path, strerror(errno));
 #endif
 }
 
 std::vector<uint8_t>
-loadCacheFile(const std::string& path, std::chrono::system_clock::duration maxAge)
+loadCacheFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge)
 {
-    // writeTime throws exception if file doesn't exist
-    auto duration = std::chrono::system_clock::now() - writeTime(path);
-    if (duration > maxAge)
+    // last_write_time throws exception if file doesn't exist
+    auto writeTime = std::filesystem::last_write_time(path);
+    if (decltype(writeTime)::clock::now() - writeTime > maxAge)
         throw std::runtime_error("file too old");
 
-    JAMI_DBG("Loading cache file '%.*s'", (int) path.size(), path.c_str());
-    return loadFile(path);
+    JAMI_LOG("Loading cache file '{}'", path);
+    return dhtnet::fileutils::loadFile(path);
 }
 
 std::string
-loadCacheTextFile(const std::string& path, std::chrono::system_clock::duration maxAge)
+loadCacheTextFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge)
 {
-    // writeTime throws exception if file doesn't exist
-    auto duration = std::chrono::system_clock::now() - writeTime(path);
-    if (duration > maxAge)
+    // last_write_time throws exception if file doesn't exist
+    auto writeTime = std::filesystem::last_write_time(path);
+    if (decltype(writeTime)::clock::now() - writeTime > maxAge)
         throw std::runtime_error("file too old");
 
-    JAMI_DBG("Loading cache file '%.*s'", (int) path.size(), path.c_str());
+    JAMI_LOG("Loading cache file '{}'", path);
     return loadTextFile(path);
 }
 
-static size_t
-dirent_buf_size(UNUSED DIR* dirp)
+ArchiveStorageData
+readArchive(const std::filesystem::path& path, std::string_view scheme, const std::string& pwd)
 {
-    long name_max;
-#if defined(HAVE_FPATHCONF) && defined(HAVE_DIRFD) && defined(_PC_NAME_MAX)
-    name_max = fpathconf(dirfd(dirp), _PC_NAME_MAX);
-    if (name_max == -1)
-#if defined(NAME_MAX)
-        name_max = (NAME_MAX > 255) ? NAME_MAX : 255;
-#else
-        return (size_t) (-1);
-#endif
-#else
-#if defined(NAME_MAX)
-    name_max = (NAME_MAX > 255) ? NAME_MAX : 255;
-#else
-#error "buffer size for readdir_r cannot be determined"
-#endif
-#endif
-    size_t name_end = (size_t) offsetof(struct dirent, d_name) + name_max + 1;
-    return name_end > sizeof(struct dirent) ? name_end : sizeof(struct dirent);
-}
-
-std::vector<std::string>
-readDirectory(const std::string& dir)
-{
-    DIR* dp = opendir(dir.c_str());
-    if (!dp)
-        return {};
-
-    size_t size = dirent_buf_size(dp);
-    if (size == (size_t) (-1))
-        return {};
-    std::vector<uint8_t> buf(size);
-    dirent* entry;
-
-    std::vector<std::string> files;
-#ifndef _WIN32
-    while (!readdir_r(dp, reinterpret_cast<dirent*>(buf.data()), &entry) && entry) {
-#else
-    while ((entry = readdir(dp)) != nullptr) {
-#endif
-        std::string fname {entry->d_name};
-        if (fname == "." || fname == "..")
-            continue;
-        files.emplace_back(std::move(fname));
-    }
-    closedir(dp);
-    return files;
-} // namespace fileutils
-
-std::vector<uint8_t>
-readArchive(const std::string& path, const std::string& pwd)
-{
-    JAMI_DBG("Reading archive from %s", path.c_str());
+    JAMI_LOG("Reading archive from {} with scheme '{}'", path, scheme);
 
     auto isUnencryptedGzip = [](const std::vector<uint8_t>& data) {
         // NOTE: some webserver modify gzip files and this can end with a gunzip in a gunzip
@@ -553,66 +322,88 @@ readArchive(const std::string& path, const std::string& pwd)
         try {
             data = archiver::decompress(data);
         } catch (const std::exception& e) {
-            JAMI_ERR("Error decrypting archive: %s", e.what());
+            JAMI_ERROR("Error decrypting archive: {}", e.what());
             throw e;
         }
     };
 
-    std::vector<uint8_t> data;
+    ArchiveStorageData ret;
+
     // Read file
     try {
-        data = loadFile(path);
+        ret.data = dhtnet::fileutils::loadFile(path);
     } catch (const std::exception& e) {
         JAMI_ERR("Error loading archive: %s", e.what());
         throw e;
     }
 
-    if (isUnencryptedGzip(data)) {
+    if (isUnencryptedGzip(ret.data)) {
         if (!pwd.empty())
-            JAMI_WARN() << "A gunzip in a gunzip is detected. A webserver may have a bad config";
-
-        decompress(data);
+            JAMI_WARNING("A gunzip in a gunzip is detected. A webserver may have a bad config");
+        decompress(ret.data);
     }
 
     if (!pwd.empty()) {
         // Decrypt
-        try {
-            data = dht::crypto::aesDecrypt(data, pwd);
-        } catch (const std::exception& e) {
-            JAMI_ERR("Error decrypting archive: %s", e.what());
-            throw e;
+        if (scheme == ARCHIVE_AUTH_SCHEME_KEY) {
+            try {
+                ret.salt = dht::crypto::aesGetSalt(ret.data);
+                ret.data = dht::crypto::aesDecrypt(dht::crypto::aesGetEncrypted(ret.data), base64::decode(pwd));
+            } catch (const std::exception& e) {
+                JAMI_ERROR("Error decrypting archive: {}", e.what());
+                throw e;
+            }
+        } else if (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD) {
+            try {
+                ret.salt = dht::crypto::aesGetSalt(ret.data);
+                ret.data = dht::crypto::aesDecrypt(ret.data, pwd);
+            } catch (const std::exception& e) {
+                JAMI_ERROR("Error decrypting archive: {}", e.what());
+                throw e;
+            }
         }
-        decompress(data);
-    } else if (isUnencryptedGzip(data)) {
-        JAMI_WARN() << "A gunzip in a gunzip is detected. A webserver may have a bad config";
-        decompress(data);
+        decompress(ret.data);
+    } else if (isUnencryptedGzip(ret.data)) {
+        JAMI_WARNING("A gunzip in a gunzip is detected. A webserver may have a bad config");
+        decompress(ret.data);
     }
-    return data;
+    return ret;
 }
 
 void
-writeArchive(const std::string& archive_str, const std::string& path, const std::string& password)
+writeArchive(const std::string& archive_str,
+             const std::filesystem::path& path,
+             std::string_view scheme,
+             const std::string& password,
+             const std::vector<uint8_t>& password_salt)
 {
-    JAMI_DBG("Writing archive to %s", path.c_str());
+    JAMI_LOG("Writing archive to {}", path);
 
-    if (not password.empty()) {
-        // Encrypt using provided password
-        std::vector<uint8_t> data = dht::crypto::aesEncrypt(archiver::compress(archive_str),
-                                                            password);
-        // Write
+    if (scheme == ARCHIVE_AUTH_SCHEME_KEY) {
+        // Encrypt using provided key
         try {
-            saveFile(path, data);
+            auto key = base64::decode(password);
+            auto newArchive = dht::crypto::aesEncrypt(archiver::compress(archive_str), key);
+            saveFile(path, dht::crypto::aesBuildEncrypted(newArchive, password_salt));
         } catch (const std::runtime_error& ex) {
-            JAMI_ERR("Export failed: %s", ex.what());
+            JAMI_ERROR("Export failed: {}", ex.what());
+            return;
+        }
+    } else if (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD and not password.empty()) {
+        // Encrypt using provided password
+        try {
+            saveFile(path, dht::crypto::aesEncrypt(archiver::compress(archive_str), password));
+        } catch (const std::runtime_error& ex) {
+            JAMI_ERROR("Export failed: {}", ex.what());
             return;
         }
     } else {
-        JAMI_WARN("Unsecured archiving (no password)");
-        archiver::compressGzip(archive_str, path);
+        JAMI_WARNING("Unsecured archiving (no password)");
+        archiver::compressGzip(archive_str, path.string());
     }
 }
 
-#if defined(__ANDROID__) || defined(RING_UWP) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
 #else
 static char* program_dir = NULL;
 void
@@ -626,24 +417,10 @@ set_program_dir(char* program_path)
 }
 #endif
 
-std::string
+std::filesystem::path
 get_cache_dir(const char* pkg)
 {
-#ifdef RING_UWP
-    std::string cache_path;
-    std::vector<std::string> paths;
-    paths.reserve(1);
-    emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("", &paths);
-    if (not paths.empty()) {
-        cache_path = paths[0] + DIR_SEPARATOR_STR + std::string(".cache");
-        if (fileutils::recursive_mkdir(cache_path.data(), 0700) != true) {
-            // If directory creation failed
-            if (errno != EEXIST)
-                JAMI_DBG("Cannot create directory: %s!", cache_path.c_str());
-        }
-    }
-    return cache_path;
-#elif defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     std::vector<std::string> paths;
     paths.reserve(1);
     emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("cache", &paths);
@@ -651,8 +428,7 @@ get_cache_dir(const char* pkg)
         return paths[0];
     return {};
 #elif defined(__APPLE__)
-    return get_home_dir() + DIR_SEPARATOR_STR + "Library" + DIR_SEPARATOR_STR + "Caches"
-           + DIR_SEPARATOR_STR + pkg;
+    return get_home_dir() / "Library" / "Caches" / pkg;
 #else
 #ifdef _WIN32
     const std::wstring cache_home(JAMI_CACHE_HOME);
@@ -663,17 +439,17 @@ get_cache_dir(const char* pkg)
     if (not cache_home.empty())
         return cache_home;
 #endif
-    return get_home_dir() + DIR_SEPARATOR_STR + ".cache" + DIR_SEPARATOR_STR + pkg;
+    return get_home_dir() / ".cache" / pkg;
 #endif
 }
 
-std::string
+std::filesystem::path
 get_cache_dir()
 {
     return get_cache_dir(PACKAGE);
 }
 
-std::string
+std::filesystem::path
 get_home_dir()
 {
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
@@ -683,13 +459,6 @@ get_home_dir()
     if (not paths.empty())
         return paths[0];
     return {};
-#elif defined RING_UWP
-    std::vector<std::string> paths;
-    paths.reserve(1);
-    emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("", &paths);
-    if (not paths.empty())
-        return paths[0];
-    return {};
 #elif defined _WIN32
     TCHAR path[MAX_PATH];
     if (SUCCEEDED(SHGetFolderPath(nullptr, CSIDL_PROFILE, nullptr, 0, path))) {
@@ -712,11 +481,11 @@ get_home_dir()
             return pw->pw_dir;
     }
 
-    return "";
+    return {};
 #endif
 }
 
-std::string
+std::filesystem::path
 get_data_dir(const char* pkg)
 {
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
@@ -727,88 +496,61 @@ get_data_dir(const char* pkg)
         return paths[0];
     return {};
 #elif defined(__APPLE__)
-    return get_home_dir() + DIR_SEPARATOR_STR + "Library" + DIR_SEPARATOR_STR
-           + "Application Support" + DIR_SEPARATOR_STR + pkg;
+    return get_home_dir() / "Library" / "Application Support" / pkg;
 #elif defined(_WIN32)
-    const std::wstring data_home(JAMI_DATA_HOME);
+    std::wstring data_home(JAMI_DATA_HOME);
     if (not data_home.empty())
-        return jami::to_string(data_home) + DIR_SEPARATOR_STR + pkg;
+        return std::filesystem::path(data_home) / pkg;
 
     if (!strcmp(pkg, "ring")) {
-        return get_home_dir() + DIR_SEPARATOR_STR + ".local" + DIR_SEPARATOR_STR
-               + "share" DIR_SEPARATOR_STR + pkg;
+        return get_home_dir() / ".local" / "share" / pkg;
     } else {
-        return get_home_dir() + DIR_SEPARATOR_STR + "AppData" + DIR_SEPARATOR_STR + "Local"
-               + DIR_SEPARATOR_STR + pkg;
+        return get_home_dir() / "AppData" / "Local" / pkg;
     }
-#elif defined(RING_UWP)
-    std::vector<std::string> paths;
-    paths.reserve(1);
-    emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("", &paths);
-    if (not paths.empty()) {
-        auto files_path = paths[0] + DIR_SEPARATOR_STR + std::string(".data");
-        if (fileutils::recursive_mkdir(files_path.data(), 0700) != true) {
-            // If directory creation failed
-            if (errno != EEXIST)
-                JAMI_DBG("Cannot create directory: %s!", files_path.c_str());
-        }
-        return files_path;
-    }
-    return {};
 #else
-    const std::string data_home(XDG_DATA_HOME);
+    std::string_view data_home(XDG_DATA_HOME);
     if (not data_home.empty())
-        return data_home + DIR_SEPARATOR_STR + pkg;
+        return std::filesystem::path(data_home) / pkg;
     // "If $XDG_DATA_HOME is either not set or empty, a default equal to
     // $HOME/.local/share should be used."
-    return get_home_dir() + DIR_SEPARATOR_STR ".local" DIR_SEPARATOR_STR "share" DIR_SEPARATOR_STR
-           + pkg;
+    return get_home_dir() / ".local" / "share" / pkg;
 #endif
 }
 
-std::string
+std::filesystem::path
 get_data_dir()
 {
     return get_data_dir(PACKAGE);
 }
 
-std::string
+std::filesystem::path
 get_config_dir(const char* pkg)
 {
-    std::string configdir;
+    std::filesystem::path configdir;
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     std::vector<std::string> paths;
     emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("config", &paths);
     if (not paths.empty())
-        configdir = std::move(paths[0]);
-#elif defined(RING_UWP)
-    std::vector<std::string> paths;
-    emitSignal<libjami::ConfigurationSignal::GetAppDataPath>("", &paths);
-    if (not paths.empty())
-        configdir = paths[0] + DIR_SEPARATOR_STR + std::string(".config");
+        configdir = std::filesystem::path(paths[0]);
 #elif defined(__APPLE__)
-    configdir = fileutils::get_home_dir() + DIR_SEPARATOR_STR + "Library" + DIR_SEPARATOR_STR
-                + "Application Support" + DIR_SEPARATOR_STR + pkg;
+    configdir = fileutils::get_home_dir() / "Library" / "Application Support" / pkg;
 #elif defined(_WIN32)
-    const std::wstring xdg_env(JAMI_CONFIG_HOME);
+    std::wstring xdg_env(JAMI_CONFIG_HOME);
     if (not xdg_env.empty()) {
-        configdir = jami::to_string(xdg_env) + DIR_SEPARATOR_STR + pkg;
+        configdir = std::filesystem::path(xdg_env) / pkg;
     } else if (!strcmp(pkg, "ring")) {
-        configdir = fileutils::get_home_dir() + DIR_SEPARATOR_STR + ".config" + DIR_SEPARATOR_STR
-                    + pkg;
+        configdir = fileutils::get_home_dir() / ".config" / pkg;
     } else {
-        configdir = fileutils::get_home_dir() + DIR_SEPARATOR_STR + "AppData" + DIR_SEPARATOR_STR
-                    + "Local" + DIR_SEPARATOR_STR + pkg;
+        configdir = fileutils::get_home_dir() / "AppData" / "Local" / pkg;
     }
 #else
-    const std::string xdg_env(XDG_CONFIG_HOME);
+    std::string xdg_env(XDG_CONFIG_HOME);
     if (not xdg_env.empty())
-        configdir = xdg_env + DIR_SEPARATOR_STR + pkg;
+        configdir = std::filesystem::path(xdg_env) / pkg;
     else
-        configdir = fileutils::get_home_dir() + DIR_SEPARATOR_STR + ".config" + DIR_SEPARATOR_STR
-                    + pkg;
+        configdir = fileutils::get_home_dir() / ".config" / pkg;
 #endif
-    if (fileutils::recursive_mkdir(configdir.data(), 0700) != true) {
+    if (dhtnet::fileutils::recursive_mkdir(configdir, 0700) != true) {
         // If directory creation failed
         if (errno != EEXIST)
             JAMI_DBG("Cannot create directory: %s!", configdir.c_str());
@@ -816,41 +558,19 @@ get_config_dir(const char* pkg)
     return configdir;
 }
 
-std::string
+std::filesystem::path
 get_config_dir()
 {
     return get_config_dir(PACKAGE);
 }
 
-bool
-recursive_mkdir(const std::string& path, mode_t mode)
-{
-#ifndef _WIN32
-    if (mkdir(path.data(), mode) != 0) {
-#else
-    if (_wmkdir(jami::to_wstring(path.data()).c_str()) != 0) {
-#endif
-        if (errno == ENOENT) {
-            recursive_mkdir(path.substr(0, path.find_last_of(DIR_SEPARATOR_CH)), mode);
-#ifndef _WIN32
-            if (mkdir(path.data(), mode) != 0) {
-#else
-            if (_wmkdir(jami::to_wstring(path.data()).c_str()) != 0) {
-#endif
-                JAMI_ERR("Could not create directory.");
-                return false;
-            }
-        }
-    } // namespace jami
-    return true;
-}
-
 #ifdef _WIN32
 bool
 eraseFile_win32(const std::string& path, bool dosync)
 {
-    // Note: from https://learn.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-deletefilea#remarks
-    // To delete a read-only file, first you must remove the read-only attribute.
+    // Note: from
+    // https://learn.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-deletefilea#remarks To
+    // delete a read-only file, first you must remove the read-only attribute.
     SetFileAttributesA(path.c_str(), GetFileAttributesA(path.c_str()) & ~FILE_ATTRIBUTE_READONLY);
     HANDLE h
         = CreateFileA(path.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
@@ -918,7 +638,7 @@ eraseFile_posix(const std::string& path, bool dosync)
         return false;
     }
     // Remove read-only flag if possible
-    chmod(path.c_str(), st.st_mode | (S_IWGRP+S_IWUSR) );
+    chmod(path.c_str(), st.st_mode | (S_IWGRP + S_IWUSR));
 
     int fd = open(path.c_str(), O_WRONLY);
     if (fd == -1) {
@@ -964,82 +684,26 @@ eraseFile(const std::string& path, bool dosync)
 }
 
 int
-remove(const std::string& path, bool erase)
+remove(const std::filesystem::path& path, bool erase)
 {
-    if (erase and isFile(path, false) and !hasHardLink(path))
-        eraseFile(path, true);
+    if (erase and dhtnet::fileutils::isFile(path, false) and !dhtnet::fileutils::hasHardLink(path))
+        eraseFile(path.string(), true);
 
 #ifdef _WIN32
     // use Win32 api since std::remove will not unlink directory in use
-    if (isDirectory(path))
-        return !RemoveDirectory(jami::to_wstring(path).c_str());
+    if (std::filesystem::is_directory(path))
+        return !RemoveDirectory(path.c_str());
 #endif
 
-    return std::remove(path.c_str());
-}
-
-int
-removeAll(const std::string& path, bool erase)
-{
-    if (path.empty())
-        return -1;
-    if (isDirectory(path) and !isSymLink(path)) {
-        auto dir = path;
-        if (dir.back() != DIR_SEPARATOR_CH)
-            dir += DIR_SEPARATOR_CH;
-        for (auto& entry : fileutils::readDirectory(dir))
-            removeAll(dir + entry, erase);
-    }
-    return remove(path, erase);
-}
-
-void
-openStream(std::ifstream& file, const std::string& path, std::ios_base::openmode mode)
-{
-#ifdef _WIN32
-    file.open(jami::to_wstring(path), mode);
-#else
-    file.open(path, mode);
-#endif
-}
-
-void
-openStream(std::ofstream& file, const std::string& path, std::ios_base::openmode mode)
-{
-#ifdef _WIN32
-    file.open(jami::to_wstring(path), mode);
-#else
-    file.open(path, mode);
-#endif
-}
-
-std::ifstream
-ifstream(const std::string& path, std::ios_base::openmode mode)
-{
-#ifdef _WIN32
-    return std::ifstream(jami::to_wstring(path), mode);
-#else
-    return std::ifstream(path, mode);
-#endif
-}
-
-std::ofstream
-ofstream(const std::string& path, std::ios_base::openmode mode)
-{
-#ifdef _WIN32
-    return std::ofstream(jami::to_wstring(path), mode);
-#else
-    return std::ofstream(path, mode);
-#endif
+    return std::remove(path.string().c_str());
 }
 
 int64_t
-size(const std::string& path)
+size(const std::filesystem::path& path)
 {
     int64_t size = 0;
     try {
-        std::ifstream file;
-        openStream(file, path, std::ios::binary | std::ios::in);
+        std::ifstream file(path, std::ios::binary | std::ios::in);
         file.seekg(0, std::ios_base::end);
         size = file.tellg();
         file.close();
@@ -1049,16 +713,15 @@ size(const std::string& path)
 }
 
 std::string
-sha3File(const std::string& path)
+sha3File(const std::filesystem::path& path)
 {
     sha3_512_ctx ctx;
     sha3_512_init(&ctx);
 
-    std::ifstream file;
     try {
-        if (!fileutils::isFile(path))
+        if (not std::filesystem::is_regular_file(path))
             return {};
-        openStream(file, path, std::ios::binary | std::ios::in);
+        std::ifstream file(path, std::ios::binary | std::ios::in);
         if (!file)
             return {};
         std::vector<char> buffer(8192, 0);
@@ -1067,7 +730,6 @@ sha3File(const std::string& path)
             std::streamsize readSize = file.gcount();
             sha3_512_update(&ctx, readSize, (const uint8_t*) buffer.data());
         }
-        file.close();
     } catch (...) {
         return {};
     }
@@ -1084,21 +746,14 @@ sha3File(const std::string& path)
 }
 
 std::string
-sha3sum(const std::vector<uint8_t>& buffer)
+sha3sum(const uint8_t* data, size_t size)
 {
     sha3_512_ctx ctx;
     sha3_512_init(&ctx);
-    sha3_512_update(&ctx, buffer.size(), (const uint8_t*) buffer.data());
-
+    sha3_512_update(&ctx, size, data);
     unsigned char digest[SHA3_512_DIGEST_SIZE];
     sha3_512_digest(&ctx, SHA3_512_DIGEST_SIZE, digest);
-
-    char hash[SHA3_512_DIGEST_SIZE * 2];
-
-    for (int i = 0; i < SHA3_512_DIGEST_SIZE; ++i)
-        pj_val_to_hex_digit(digest[i], &hash[2 * i]);
-
-    return {hash, SHA3_512_DIGEST_SIZE * 2};
+    return dht::toHex(digest, SHA3_512_DIGEST_SIZE);
 }
 
 int
@@ -1112,11 +767,11 @@ accessFile(const std::string& file, int mode)
 }
 
 uint64_t
-lastWriteTimeInSeconds(const std::string& filePath)
+lastWriteTimeInSeconds(const std::filesystem::path& filePath)
 {
     return std::chrono::duration_cast<std::chrono::seconds>(
-            std::filesystem::last_write_time(std::filesystem::path(filePath))
-                    .time_since_epoch()).count();
+               std::filesystem::last_write_time(filePath).time_since_epoch())
+        .count();
 }
 
 } // namespace fileutils
