@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *  Author : Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -74,7 +74,7 @@ AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
         findCertificate(d.first, [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
             if (not crt)
                 return;
-            // std::lock_guard<std::mutex> lock(deviceListMutex_);
+            // std::lock_guard lock(deviceListMutex_);
             foundAccountDevice(crt, d.second);
         });
     }
@@ -83,7 +83,7 @@ AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
                         [this, d](const std::shared_ptr<dht::crypto::Certificate>& crt) {
                             if (not crt || crt->getLongId() != d.first)
                                 return;
-                            // std::lock_guard<std::mutex> lock(deviceListMutex_);
+                            // std::lock_guard lock(deviceListMutex_);
                             foundAccountDevice(crt, d.second.name);
                         });
     }
@@ -103,7 +103,6 @@ AccountManager::onSyncData(DeviceSync&& sync, bool checkDevice)
                                         false,
                                         tr.second.conversationId,
                                         {});
-    info_->contacts->saveTrustRequests();
 }
 
 dht::crypto::Identity
@@ -181,6 +180,7 @@ AccountManager::useIdentity(const std::string& accountId,
                             const std::string& username,
                             const OnChangeCallback& onChange)
 {
+    accountId_ = accountId;
     if (receipt.empty() or receiptSignature.empty())
         return nullptr;
 
@@ -272,24 +272,26 @@ AccountManager::announceFromReceipt(const std::string& receipt)
 }
 
 void
-AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dcb)
+AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dcb, bool publishPresence)
 {
     // Put device announcement
     if (info_->announce) {
         auto h = dht::InfoHash(info_->accountId);
-        dht_->put(
-            h,
-            info_->announce,
-            [dcb = std::move(dcb), h](bool ok) {
-                if (ok)
-                    JAMI_DEBUG("device announced at {}", h.toString());
-                // We do not care about the status, it's a permanent put, if this fail,
-                // this means the DHT is disconnected but the put will be retried when connected.
-                if (dcb)
-                    dcb();
-            },
-            {},
-            true);
+        if (publishPresence) {
+            dht_->put(
+                h,
+                info_->announce,
+                [dcb = std::move(dcb), h](bool ok) {
+                    if (ok)
+                        JAMI_DEBUG("device announced at {}", h.toString());
+                    // We do not care about the status, it's a permanent put, if this fail,
+                    // this means the DHT is disconnected but the put will be retried when connected.
+                    if (dcb)
+                        dcb();
+                },
+                {},
+                true);
+        }
         for (const auto& crl : info_->identity.second->issuer->getRevocationLists())
             dht_->put(h, crl, dht::DoneCallback {}, {}, true);
         dht_->listen<DeviceAnnouncement>(h, [this, cb = std::move(cb)](DeviceAnnouncement&& dev) {
@@ -344,13 +346,18 @@ AccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dc
                         auto details = info_->contacts->getContactDetails(peer_account);
                         auto oldConvIt = details.find(libjami::Account::TrustRequest::CONVERSATIONID);
                         if (oldConvIt != details.end() && oldConvIt->second != "") {
-                            if (conversationId == oldConvIt->second)
+                            if (conversationId == oldConvIt->second) {
+                                // Here, it's possible that we already have accepted the conversation
+                                // but contact were offline and sync failed.
+                                // So, retrigger the callback so upper layer will clone conversation if needed
+                                // instead of getting stuck in sync.
+                                info_->contacts->acceptConversation(conversationId, v.owner->getLongId().toString());
                                 return;
+                            }
                             conversationId = oldConvIt->second;
                             JAMI_WARNING("Accept with old convId: {}", conversationId);
                         }
                         sendTrustRequestConfirm(peer_account, conversationId);
-                        info_->contacts->saveTrustRequests();
                     }
             });
         return true;
@@ -545,7 +552,7 @@ AccountManager::updateContactConversation(const std::string& uri, const std::str
 }
 
 std::vector<std::map<std::string, std::string>>
-AccountManager::getContacts() const
+AccountManager::getContacts(bool includeRemoved) const
 {
     if (not info_) {
         JAMI_ERR("getContacts(): account not loaded");
@@ -556,6 +563,8 @@ AccountManager::getContacts() const
     ret.reserve(contacts.size());
 
     for (const auto& c : contacts) {
+        if (!c.second.isActive() && !includeRemoved && !c.second.isBanned())
+            continue;
         auto details = c.second.toMap();
         if (not details.empty()) {
             details["id"] = c.first.toString();
