@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2019-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2019-2024 Savoir-faire Linux Inc.
  *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -54,7 +54,6 @@ constexpr auto EUNAUTHORIZED = 4;
 constexpr auto ECOMMIT = 5;
 
 class JamiAccount;
-class ChannelSocket;
 
 struct LogOptions
 {
@@ -128,6 +127,13 @@ struct ConversationMember
     }
 };
 
+enum class CallbackResult { Skip, Break, Ok };
+
+using PreConditionCb
+    = std::function<CallbackResult(const std::string&, const GitAuthor&, const GitCommit&)>;
+using PostConditionCb
+    = std::function<bool(const std::string&, const GitAuthor&, ConversationCommit&)>;
+
 /**
  * This class gives access to the git repository that represents the conversation
  */
@@ -152,12 +158,13 @@ public:
      * @param account           The account getting the conversation
      * @param deviceId          Remote device
      * @param conversationId    Conversation to clone
-     * @param socket            Socket used to clone
+     * @param checkCommitCb     Used if commits should be treated
      */
     static LIBJAMI_TESTABLE std::unique_ptr<ConversationRepository> cloneConversation(
         const std::shared_ptr<JamiAccount>& account,
         const std::string& deviceId,
-        const std::string& conversationId);
+        const std::string& conversationId,
+        std::function<void(std::vector<ConversationCommit>)>&& checkCommitCb = {});
 
     /**
      * Open a conversation repository for an account and an id
@@ -220,16 +227,14 @@ public:
      * @return a list of commits
      */
     std::vector<ConversationCommit> log(const LogOptions& options = {}) const;
+    void log(PreConditionCb&& preCondition,
+            std::function<void(ConversationCommit&&)>&& emplaceCb,
+            PostConditionCb&& postCondition,
+            const std::string& from = "",
+            bool logIfNotFound = true) const;
     std::optional<ConversationCommit> getCommit(const std::string& commitId,
                                                 bool logIfNotFound = true) const;
 
-    /**
-     * Search in the conversation via a filter
-     * @param filter    Parameters for the search
-     * @return matching commits
-     */
-    std::vector<std::map<std::string, std::string>> search(const Filter& filter) const;
-
     /**
      * Get parent via topological + date sort in branch main of a commit
      * @param commitId      id to choice
@@ -330,7 +335,7 @@ public:
      */
     std::pair<std::vector<ConversationCommit>, bool> validFetch(
         const std::string& remoteDevice) const;
-    bool validClone() const;
+    bool validClone(std::function<void(std::vector<ConversationCommit>)>&& checkCommitCb) const;
 
     /**
      * Delete branch with remote
@@ -402,7 +407,7 @@ public:
     /**
      * Convert ConversationCommit to MapStringString for the client
      */
-    std::vector<std::map<std::string, std::string>> convCommitToMap(
+    std::vector<std::map<std::string, std::string>> convCommitsToMap(
         const std::vector<ConversationCommit>& commits) const;
     std::optional<std::map<std::string, std::string>> convCommitToMap(
         const ConversationCommit& commit) const;
