@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2021-2024 Savoir-faire Linux Inc.
  *
  *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
  *
@@ -32,8 +32,8 @@ TransferChannelHandler::TransferChannelHandler(const std::shared_ptr<JamiAccount
     , account_(account)
     , connectionManager_(cm)
 {
-    auto acc = account_.lock();
-    idPath_ = fileutils::get_data_dir() / acc->getAccountID();
+    if (auto acc = account_.lock())
+        idPath_ = fileutils::get_data_dir() / acc->getAccountID();
 }
 
 TransferChannelHandler::~TransferChannelHandler() {}
@@ -51,9 +51,12 @@ TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate
     auto acc = account_.lock();
     if (!acc || !cert || !cert->issuer)
         return false;
+    auto cm = acc->convModule(true);
+    if (!cm)
+        return false;
     auto uri = cert->issuer->getId().toString();
     // Else, check if it's a profile or file in a conversation.
-    auto idstr = name.substr(16);
+    auto idstr = std::string_view(name).substr(DATA_TRANSFER_SCHEME.size());
     // Remove arguments for now
     auto sep = idstr.find_last_of('?');
     idstr = idstr.substr(0, sep);
@@ -63,7 +66,7 @@ TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate
     }
     sep = idstr.find('/');
     auto lastSep = idstr.find_last_of('/');
-    auto conversationId = idstr.substr(0, sep);
+    auto conversationId = std::string(idstr.substr(0, sep));
     auto fileHost = idstr.substr(sep + 1, lastSep - sep - 1);
     auto fileId = idstr.substr(lastSep + 1);
     if (fileHost == acc->currentDeviceId())
@@ -72,7 +75,7 @@ TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate
     // Check if peer is member of the conversation
     if (fileId == fmt::format("{}.vcf", acc->getUsername()) || fileId == "profile.vcf") {
         // Or a member from the conversation
-        auto members = acc->convModule()->getConversationMembers(conversationId);
+        auto members = cm->getConversationMembers(conversationId);
         return std::find_if(members.begin(), members.end(), [&](auto m) { return m["uri"] == uri; })
                != members.end();
     } else if (fileHost == "profile") {
@@ -80,9 +83,9 @@ TransferChannelHandler::onRequest(const std::shared_ptr<dht::crypto::Certificate
         return uri == acc->getUsername();
     }
 
-    return acc->convModule()->onFileChannelRequest(conversationId,
+    return cm->onFileChannelRequest(conversationId,
                                                    uri,
-                                                   fileId,
+                                                   std::string(fileId),
                                                    acc->sha3SumVerify());
 }
 
@@ -95,7 +98,8 @@ TransferChannelHandler::onReady(const std::shared_ptr<dht::crypto::Certificate>&
     if (!acc)
         return;
 
-    auto idstr = name.substr(16);
+    // Remove scheme
+    auto idstr = name.substr(DATA_TRANSFER_SCHEME.size());
     // Parse arguments
     auto sep = idstr.find_last_of('?');
     std::string arguments;
@@ -163,7 +167,7 @@ TransferChannelHandler::onReady(const std::shared_ptr<dht::crypto::Certificate>&
         return;
     } else if (isContactProfile && fileId.find(".vcf") != std::string::npos) {
         auto path = acc->dataTransfer()->profilePath(fileId.substr(0, fileId.size() - 4));
-        acc->dataTransfer()->transferFile(channel, fileId, "", path);
+        acc->dataTransfer()->transferFile(channel, fileId, "", path.string());
         return;
     } else if (fileId == "profile.vcf") {
         acc->dataTransfer()->onIncomingProfile(channel, sha3Sum);
@@ -177,8 +181,8 @@ TransferChannelHandler::onReady(const std::shared_ptr<dht::crypto::Certificate>&
         return;
     }
     auto interactionId = fileId.substr(0, sep);
-    std::string path = dt->path(fileId);
-    dt->transferFile(channel, fileId, interactionId, path, start, end);
+    auto path = dt->path(fileId);
+    dt->transferFile(channel, fileId, interactionId, path.string(), start, end);
 }
 
 } // namespace jami
\ No newline at end of file
