@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
  *  Author: Vivien Didelot <vivien.didelot@savoirfairelinux.com>
@@ -55,7 +55,7 @@ namespace video {
 static constexpr unsigned default_grab_width = 640;
 static constexpr unsigned default_grab_height = 480;
 
-VideoInput::VideoInput(VideoInputMode inputMode, const std::string& id_)
+VideoInput::VideoInput(VideoInputMode inputMode, const std::string& resource, const std::string& sink)
     : VideoGenerator::VideoGenerator()
     , loop_(std::bind(&VideoInput::setup, this),
             std::bind(&VideoInput::process, this),
@@ -63,26 +63,22 @@ VideoInput::VideoInput(VideoInputMode inputMode, const std::string& id_)
 {
     inputMode_ = inputMode;
     if (inputMode_ == VideoInputMode::Undefined) {
-#if (defined(__ANDROID__) || defined(RING_UWP) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS))
+#if (defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS))
         inputMode_ = VideoInputMode::ManagedByClient;
 #else
         inputMode_ = VideoInputMode::ManagedByDaemon;
 #endif
     }
-#ifdef __ANDROID__
-    sink_ = Manager::instance().createSinkClient(id_);
-#else
-    if (inputMode_ == VideoInputMode::ManagedByDaemon) {
-        sink_ = Manager::instance().createSinkClient(id_);
-    }
-#endif
-    switchInput(id_);
+    sink_ = Manager::instance().createSinkClient(sink.empty() ? resource : sink);
+    switchInput(resource);
 }
 
 VideoInput::~VideoInput()
 {
     isStopped_ = true;
     if (videoManagedByClient()) {
+        // Stop the video sink for videos that are managed by the client.
+        cleanup();
         emitSignal<libjami::VideoSignal::StopCapture>(decOpts_.input);
         capturing_ = false;
         return;
@@ -176,11 +172,9 @@ void
 VideoInput::process()
 {
     if (playingFile_) {
-        if (paused_) {
+        if (paused_ || !decoder_->emitFrame(false)) {
             std::this_thread::sleep_for(std::chrono::milliseconds(20));
-            return;
         }
-        decoder_->emitFrame(false);
         return;
     }
     if (switchPending_)
@@ -255,15 +249,33 @@ VideoInput::configureFilePlayback(const std::string&,
 
     decoder_ = std::move(decoder);
     playingFile_ = true;
-    loop_.start();
 
+    // For DBUS it is imperative that we start the sink before setting the frame size
+    sink_->start();
     /* Signal the client about readable sink */
     sink_->setFrameSize(decoder_->getWidth(), decoder_->getHeight());
+
+    loop_.start();
+
+    decOpts_.width = ((decoder_->getWidth() >> 3) << 3);
+    decOpts_.height = ((decoder_->getHeight() >> 3) << 3);
+    decOpts_.framerate = decoder_->getFps();
+    AVPixelFormat fmt = decoder_->getPixelFormat();
+    if (fmt != AV_PIX_FMT_NONE) {
+        decOpts_.pixel_format = av_get_pix_fmt_name(fmt);
+    } else {
+        JAMI_WARN("Could not determine pixel format, using default");
+        decOpts_.pixel_format = av_get_pix_fmt_name(AV_PIX_FMT_YUV420P);
+    }
+
+    if (onSuccessfulSetup_)
+        onSuccessfulSetup_(MEDIA_VIDEO, 0);
+    foundDecOpts(decOpts_);
+    futureDecOpts_ = foundDecOpts_.get_future().share();
 }
 
 void
-VideoInput::setRecorderCallback(
-    const std::function<void(const MediaStream& ms)>& cb)
+VideoInput::setRecorderCallback(const std::function<void(const MediaStream& ms)>& cb)
 {
     recorderCallback_ = cb;
     if (decoder_)
@@ -501,7 +513,7 @@ VideoInput::initWindowsGrab(const std::string& display)
     DeviceParams p = jami::getVideoDeviceMonitor().getDeviceParams(DEVICE_DESKTOP);
     if (winHandlePos != std::string::npos) {
         p.input = display.substr(winHandlePos + windowIdStr.size()); // "HANDLE";
-        p.name  = display.substr(winHandlePos + windowIdStr.size()); // "HANDLE";
+        p.name = display.substr(winHandlePos + windowIdStr.size());  // "HANDLE";
         p.is_area = 0;
     } else {
         p.input = display.substr(1);
@@ -586,7 +598,7 @@ void
 VideoInput::restart()
 {
     if (loop_.isStopping())
-        switchInput(currentResource_);
+        switchInput(resource_);
 }
 
 std::shared_future<DeviceParams>
@@ -599,14 +611,14 @@ VideoInput::switchInput(const std::string& resource)
         return {};
     }
 
-    currentResource_ = resource;
+    resource_ = resource;
     decOptsFound_ = false;
 
     std::promise<DeviceParams> p;
     foundDecOpts_.swap(p);
 
     // Switch off video input?
-    if (resource.empty()) {
+    if (resource_.empty()) {
         clearOptions();
         futureDecOpts_ = foundDecOpts_.get_future();
         startLoop();
@@ -616,15 +628,15 @@ VideoInput::switchInput(const std::string& resource)
     // Supported MRL schemes
     static const std::string sep = libjami::Media::VideoProtocolPrefix::SEPARATOR;
 
-    const auto pos = resource.find(sep);
+    const auto pos = resource_.find(sep);
     if (pos == std::string::npos)
         return {};
 
-    const auto prefix = resource.substr(0, pos);
-    if ((pos + sep.size()) >= resource.size())
+    const auto prefix = resource_.substr(0, pos);
+    if ((pos + sep.size()) >= resource_.size())
         return {};
 
-    const auto suffix = resource.substr(pos + sep.size());
+    const auto suffix = resource_.substr(pos + sep.size());
 
     bool ready = false;
 
@@ -687,16 +699,11 @@ VideoInput::setSink(const std::string& sinkId)
 }
 
 void
-VideoInput::setFrameSize(const int width, const int height)
-{
-    /* Signal the client about readable sink */
-    sink_->setFrameSize(width, height);
-}
-
-void
-VideoInput::setupSink()
+VideoInput::setupSink(const int width, const int height)
 {
     setup();
+    /* Signal the client about readable sink */
+    sink_->setFrameSize(width, height);
 }
 
 void
