@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2020-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2020-2024 Savoir-faire Linux Inc.
  *
  *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
  *
@@ -126,6 +126,30 @@ JamiPluginManager::getInstalledPlugins()
     return pluginsPaths;
 }
 
+bool
+JamiPluginManager::checkPluginCertificatePublicKey(const std::string& oldJplPath, const std::string& newJplPath)
+{
+    std::map<std::string, std::string> oldDetails = PluginUtils::parseManifestFile(PluginUtils::manifestPath(oldJplPath), oldJplPath);
+    if (
+        oldDetails.empty() ||
+        !std::filesystem::is_regular_file(oldJplPath + DIR_SEPARATOR_CH + oldDetails["id"] + ".crt") ||
+        !std::filesystem::is_regular_file(newJplPath)
+    )
+        return false;
+    try {
+        auto oldCert = PluginUtils::readPluginCertificate(oldJplPath, oldDetails["id"]);
+        auto newCert = PluginUtils::readPluginCertificateFromArchive(newJplPath);
+        if (!oldCert || !newCert) {
+            return false;
+        }
+        return oldCert->getPublicKey() == newCert->getPublicKey();
+    } catch (const std::exception& e) {
+        JAMI_ERR() << e.what();
+        return false;
+    }
+    return true;
+}
+
 bool
 JamiPluginManager::checkPluginCertificateValidity(dht::crypto::Certificate* cert)
 {
@@ -256,6 +280,8 @@ JamiPluginManager::installPlugin(const std::string& jplPath, bool force)
                 } else {
                     std::string installedVersion = alreadyInstalledManifestMap.at("version");
                     if (version > installedVersion) {
+                        if(!checkPluginCertificatePublicKey(destinationDir, jplPath))
+                            return CERTIFICATE_VERIFICATION_FAILED;
                         r = uninstallPlugin(destinationDir);
                         if (r == SUCCESS) {
                             archiver::uncompressArchive(jplPath,
@@ -338,7 +364,7 @@ JamiPluginManager::loadPlugins()
 {
 #ifdef ENABLE_PLUGIN
     bool status = true;
-    auto loadedPlugins = getLoadedPlugins();
+    auto loadedPlugins = jami::Manager::instance().pluginPreferences.getLoadedPlugins();
     for (const auto& pluginPath : loadedPlugins) {
         status &= loadPlugin(pluginPath);
     }
@@ -432,7 +458,7 @@ JamiPluginManager::setPluginPreference(const std::filesystem::path& rootPath,
         pluginUserPreferencesMap[key] = value;
         auto preferencesValuesFilePath
             = PluginPreferencesUtils::valuesFilePath(rootPath, acc);
-        std::lock_guard<std::mutex> guard(dhtnet::fileutils::getFileLock(preferencesValuesFilePath));
+        std::lock_guard guard(dhtnet::fileutils::getFileLock(preferencesValuesFilePath));
         std::ofstream fs(preferencesValuesFilePath, std::ios::binary);
         if (!fs.good()) {
             if (force) {
