@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2022-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2022-2024 Savoir-faire Linux Inc.
  *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 #include "conversation/conversationcommon.h"
 #include "manager.h"
 #include "media_const.h"
+#include "sip/sipcall.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -45,7 +46,7 @@ struct ConvData
     bool conferenceRemoved {false};
     std::string hostState {};
     std::string state {};
-    std::vector<std::map<std::string, std::string>> messages {};
+    std::vector<libjami::SwarmMessage> messages {};
 };
 
 class ConversationCallTest : public CppUnit::TestFixture
@@ -85,6 +86,7 @@ private:
     void testCallSelfIfDefaultHost();
     void testNeedsHost();
     void testAudioOnly();
+    void testJoinAfterMuteHost();
 
     CPPUNIT_TEST_SUITE(ConversationCallTest);
     CPPUNIT_TEST(testActiveCalls);
@@ -98,6 +100,7 @@ private:
     CPPUNIT_TEST(testCallSelfIfDefaultHost);
     CPPUNIT_TEST(testNeedsHost);
     CPPUNIT_TEST(testAudioOnly);
+    CPPUNIT_TEST(testJoinAfterMuteHost);
     CPPUNIT_TEST_SUITE_END();
 };
 
@@ -154,10 +157,10 @@ ConversationCallTest::connectSignals()
                 carlaData_.id = conversationId;
             cv.notify_one();
         }));
-    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::MessageReceived>(
+    confHandlers.insert(libjami::exportable_callback<libjami::ConversationSignal::SwarmMessageReceived>(
         [&](const std::string& accountId,
             const std::string& conversationId,
-            std::map<std::string, std::string> message) {
+            const libjami::SwarmMessage& message) {
             if (accountId == aliceId && aliceData_.id == conversationId)
                 aliceData_.messages.emplace_back(message);
             if (accountId == bobId && bobData_.id == conversationId)
@@ -291,8 +294,8 @@ ConversationCallTest::testActiveCalls()
     aliceData_.messages.clear();
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     // should get message
-    cv.wait_for(lk, 30s, [&]() { return !aliceData_.messages.empty(); });
-    CPPUNIT_ASSERT(aliceData_.messages[0]["type"] == "application/call-history+json");
+    cv.wait_for(lk, 30s, [&]() { return !aliceData_.conferenceChanged && !aliceData_.messages.empty(); });
+    CPPUNIT_ASSERT(aliceData_.messages.rbegin()->type == "application/call-history+json");
 
     // get active calls = 1
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 1);
@@ -303,7 +306,7 @@ ConversationCallTest::testActiveCalls()
 
     // should get message
     cv.wait_for(lk, 30s, [&]() { return !aliceData_.messages.empty(); });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages.rbegin()->body.find("duration") != aliceData_.messages.rbegin()->body.end());
 
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
@@ -349,34 +352,31 @@ ConversationCallTest::testActiveCalls3Peers()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
         return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_)
                && lastCommitIsCall(carlaData_);
     });
-    auto confId = bobData_.messages.rbegin()->at("confId");
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
     auto destination = fmt::format("rdv:{}/{}/{}/{}",
                                    bobData_.id,
-                                   bobData_.messages.rbegin()->at("uri"),
-                                   bobData_.messages.rbegin()->at("device"),
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
                                    confId);
 
     aliceData_.conferenceChanged = false;
     libjami::placeCallWithMedia(bobId, destination, {});
-    cv.wait_for(lk, 30s, [&]() {
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
         return aliceData_.conferenceChanged && bobData_.hostState == "CURRENT";
-    });
+    }));
     aliceData_.conferenceChanged = false;
-    libjami::placeCallWithMedia(carlaId, destination, {});
-    cv.wait_for(lk, 30s, [&]() {
-        return aliceData_.conferenceChanged && carlaData_.hostState == "CURRENT";
-    });
-
     // get 3 participants
-    auto callList = libjami::getParticipantList(aliceId, confId);
-    CPPUNIT_ASSERT(callList.size() == 3);
+    libjami::placeCallWithMedia(carlaId, destination, {});
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData_.conferenceChanged && carlaData_.hostState == "CURRENT" && libjami::getParticipantList(aliceId, confId).size() == 3;
+    }));
 
     // get active calls = 1
     CPPUNIT_ASSERT(libjami::getActiveCalls(bobId, bobData_.id).size() == 1);
@@ -392,9 +392,9 @@ ConversationCallTest::testActiveCalls3Peers()
         return !aliceData_.messages.empty() && !bobData_.messages.empty()
                && !carlaData_.messages.empty();
     });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
-    CPPUNIT_ASSERT(bobData_.messages[0].find("duration") != bobData_.messages[0].end());
-    CPPUNIT_ASSERT(carlaData_.messages[0].find("duration") != carlaData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages[0].body.find("duration") != aliceData_.messages[0].body.end());
+    CPPUNIT_ASSERT(bobData_.messages[0].body.find("duration") != bobData_.messages[0].body.end());
+    CPPUNIT_ASSERT(carlaData_.messages[0].body.find("duration") != carlaData_.messages[0].body.end());
 
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
@@ -440,7 +440,7 @@ ConversationCallTest::testRejoinCall()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
@@ -448,11 +448,11 @@ ConversationCallTest::testRejoinCall()
                && lastCommitIsCall(carlaData_);
     });
 
-    auto confId = bobData_.messages.rbegin()->at("confId");
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
     auto destination = fmt::format("rdv:{}/{}/{}/{}",
                                    bobData_.id,
-                                   bobData_.messages.rbegin()->at("uri"),
-                                   bobData_.messages.rbegin()->at("device"),
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
                                    confId);
 
     aliceData_.conferenceChanged = false;
@@ -500,9 +500,9 @@ ConversationCallTest::testRejoinCall()
         return !aliceData_.messages.empty() && !bobData_.messages.empty()
                && !carlaData_.messages.empty();
     });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
-    CPPUNIT_ASSERT(bobData_.messages[0].find("duration") != bobData_.messages[0].end());
-    CPPUNIT_ASSERT(carlaData_.messages[0].find("duration") != carlaData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages[0].body.find("duration") != aliceData_.messages[0].body.end());
+    CPPUNIT_ASSERT(bobData_.messages[0].body.find("duration") != bobData_.messages[0].body.end());
+    CPPUNIT_ASSERT(carlaData_.messages[0].body.find("duration") != carlaData_.messages[0].body.end());
 
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
@@ -536,7 +536,7 @@ ConversationCallTest::testParticipantHangupConfNotRemoved()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
@@ -545,9 +545,9 @@ ConversationCallTest::testParticipantHangupConfNotRemoved()
 
     auto destination = fmt::format("rdv:{}/{}/{}/{}",
                                    bobData_.id,
-                                   bobData_.messages.rbegin()->at("uri"),
-                                   bobData_.messages.rbegin()->at("device"),
-                                   bobData_.messages.rbegin()->at("confId"));
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
+                                   bobData_.messages.rbegin()->body.at("confId"));
 
     aliceData_.conferenceChanged = false;
     auto bobCallId = libjami::placeCallWithMedia(bobId, destination, {});
@@ -600,19 +600,19 @@ ConversationCallTest::testJoinFinishedCall()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
         return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_)
                && lastCommitIsCall(carlaData_);
     });
-    auto confId = bobData_.messages.rbegin()->at("confId");
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
     auto destination = fmt::format("rdv:{}/{}/{}/{}",
                                    bobData_.id,
-                                   bobData_.messages.rbegin()->at("uri"),
-                                   bobData_.messages.rbegin()->at("device"),
-                                   bobData_.messages.rbegin()->at("confId"));
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
+                                   bobData_.messages.rbegin()->body.at("confId"));
     // hangup
     aliceData_.messages.clear();
     bobData_.messages.clear();
@@ -635,7 +635,7 @@ ConversationCallTest::testJoinFinishedCall()
         return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_)
                && lastCommitIsCall(carlaData_) && bobData_.hostState == "CURRENT";
     });
-    confId = bobData_.messages.rbegin()->at("confId");
+    confId = bobData_.messages.rbegin()->body.at("confId");
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 1);
     // hangup
     aliceData_.messages.clear();
@@ -647,9 +647,9 @@ ConversationCallTest::testJoinFinishedCall()
         return !aliceData_.messages.empty() && !bobData_.messages.empty()
                && !carlaData_.messages.empty();
     });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
-    CPPUNIT_ASSERT(bobData_.messages[0].find("duration") != bobData_.messages[0].end());
-    CPPUNIT_ASSERT(carlaData_.messages[0].find("duration") != carlaData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages[0].body.find("duration") != aliceData_.messages[0].body.end());
+    CPPUNIT_ASSERT(bobData_.messages[0].body.find("duration") != bobData_.messages[0].body.end());
+    CPPUNIT_ASSERT(carlaData_.messages[0].body.find("duration") != carlaData_.messages[0].body.end());
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
 }
@@ -697,7 +697,7 @@ ConversationCallTest::testJoinFinishedCallForbidden()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
@@ -705,12 +705,12 @@ ConversationCallTest::testJoinFinishedCallForbidden()
                && lastCommitIsCall(carlaData_);
     });
 
-    auto confId = bobData_.messages.rbegin()->at("confId");
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
     auto destination = fmt::format("rdv:{}/{}/{}/{}",
                                    bobData_.id,
-                                   bobData_.messages.rbegin()->at("uri"),
-                                   bobData_.messages.rbegin()->at("device"),
-                                   bobData_.messages.rbegin()->at("confId"));
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
+                                   bobData_.messages.rbegin()->body.at("confId"));
 
     // hangup
     aliceData_.messages.clear();
@@ -738,7 +738,7 @@ ConversationCallTest::testJoinFinishedCallForbidden()
                && lastCommitIsCall(carlaData_) && bobData_.hostState == "CURRENT";
     });
 
-    confId = bobData_.messages.rbegin()->at("confId");
+    confId = bobData_.messages.rbegin()->body.at("confId");
 
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 1);
 
@@ -753,9 +753,9 @@ ConversationCallTest::testJoinFinishedCallForbidden()
         return !aliceData_.messages.empty() && !bobData_.messages.empty()
                && !carlaData_.messages.empty();
     });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
-    CPPUNIT_ASSERT(bobData_.messages[0].find("duration") != bobData_.messages[0].end());
-    CPPUNIT_ASSERT(carlaData_.messages[0].find("duration") != carlaData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages[0].body.find("duration") != aliceData_.messages[0].body.end());
+    CPPUNIT_ASSERT(bobData_.messages[0].body.find("duration") != bobData_.messages[0].body.end());
+    CPPUNIT_ASSERT(carlaData_.messages[0].body.find("duration") != carlaData_.messages[0].body.end());
 
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
@@ -787,7 +787,7 @@ ConversationCallTest::testUsePreference()
     bobData_.messages.clear();
     auto lastCommitIsProfile = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/update-profile";
+               && data.messages.rbegin()->body.at("type") == "application/update-profile";
     };
     libjami::updateConversationInfos(aliceId,
                                      aliceData_.id,
@@ -806,13 +806,13 @@ ConversationCallTest::testUsePreference()
     auto callId = libjami::placeCallWithMedia(bobId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     cv.wait_for(lk, 30s, [&]() {
         return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_);
     });
-    auto confId = bobData_.messages.rbegin()->at("confId");
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
 
     // Alice should be the host
     CPPUNIT_ASSERT(aliceAccount->getConference(confId));
@@ -837,12 +837,12 @@ ConversationCallTest::testJoinWhileActiveCall()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return lastCommitIsCall(aliceData_); }));
 
-    auto confId = aliceData_.messages.rbegin()->at("confId");
+    auto confId = aliceData_.messages.rbegin()->body.at("confId");
     libjami::addConversationMember(aliceId, aliceData_.id, bobUri);
     CPPUNIT_ASSERT(cv.wait_for(lk, 60s, [&]() { return bobData_.requestReceived; }));
 
@@ -887,7 +887,7 @@ ConversationCallTest::testCallSelfIfDefaultHost()
     bobData_.messages.clear();
     auto lastCommitIsProfile = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/update-profile";
+               && data.messages.rbegin()->body.at("type") == "application/update-profile";
     };
     libjami::updateConversationInfos(aliceId,
                                      aliceData_.id,
@@ -906,13 +906,13 @@ ConversationCallTest::testCallSelfIfDefaultHost()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, {});
     auto lastCommitIsCall = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/call-history+json";
+               && data.messages.rbegin()->body.at("type") == "application/call-history+json";
     };
     // should get message
     CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
         return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_);
     }));
-    auto confId = aliceData_.messages.rbegin()->at("confId");
+    auto confId = aliceData_.messages.rbegin()->body.at("confId");
     // Alice should be the host
     CPPUNIT_ASSERT(aliceAccount->getConference(confId));
     Manager::instance().hangupConference(aliceId, confId);
@@ -945,7 +945,7 @@ ConversationCallTest::testNeedsHost()
     bobData_.messages.clear();
     auto lastCommitIsProfile = [&](const auto& data) {
         return !data.messages.empty()
-               && data.messages.rbegin()->at("type") == "application/update-profile";
+               && data.messages.rbegin()->body.at("type") == "application/update-profile";
     };
     libjami::updateConversationInfos(aliceId,
                                      aliceData_.id,
@@ -996,7 +996,7 @@ ConversationCallTest::testAudioOnly()
     auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, mediaList);
     // should get message
     cv.wait_for(lk, 30s, [&]() { return !aliceData_.messages.empty() && !pInfos_.empty(); });
-    CPPUNIT_ASSERT(aliceData_.messages[0]["type"] == "application/call-history+json");
+    CPPUNIT_ASSERT(aliceData_.messages[0].type == "application/call-history+json");
     CPPUNIT_ASSERT(pInfos_.size() == 1);
     CPPUNIT_ASSERT(pInfos_[0]["videoMuted"] == "true");
 
@@ -1006,12 +1006,86 @@ ConversationCallTest::testAudioOnly()
 
     // should get message
     cv.wait_for(lk, 30s, [&]() { return !aliceData_.messages.empty(); });
-    CPPUNIT_ASSERT(aliceData_.messages[0].find("duration") != aliceData_.messages[0].end());
+    CPPUNIT_ASSERT(aliceData_.messages[0].body.find("duration") != aliceData_.messages[0].body.end());
 
     // get active calls = 0
     CPPUNIT_ASSERT(libjami::getActiveCalls(aliceId, aliceData_.id).size() == 0);
 }
 
+void
+ConversationCallTest::testJoinAfterMuteHost()
+{
+    connectSignals();
+
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    auto aliceUri = aliceAccount->getUsername();
+    auto bobAccount = Manager::instance().getAccount<JamiAccount>(bobId);
+    auto bobUri = bobAccount->getUsername();
+    // Start conversation
+    libjami::startConversation(aliceId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() { return !aliceData_.id.empty(); }));
+
+    libjami::addConversationMember(aliceId, aliceData_.id, bobUri);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 60s, [&]() {
+        return bobData_.requestReceived;
+    }));
+
+    aliceData_.messages.clear();
+    libjami::acceptConversationRequest(bobId, aliceData_.id);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return !bobData_.id.empty() && !aliceData_.messages.empty();
+    }));
+
+    // start call
+    aliceData_.messages.clear();
+    bobData_.messages.clear();
+    carlaData_.messages.clear();
+    std::vector<std::map<std::string, std::string>> mediaList;
+    std::map<std::string, std::string> mediaAttribute
+        = {{libjami::Media::MediaAttributeKey::MEDIA_TYPE,
+            libjami::Media::MediaAttributeValue::AUDIO},
+            {libjami::Media::MediaAttributeKey::ENABLED, TRUE_STR},
+            {libjami::Media::MediaAttributeKey::MUTED, FALSE_STR},
+            {libjami::Media::MediaAttributeKey::SOURCE, ""},
+            {libjami::Media::MediaAttributeKey::LABEL, "audio_0"}};
+    mediaList.emplace_back(mediaAttribute);
+    auto callId = libjami::placeCallWithMedia(aliceId, "swarm:" + aliceData_.id, mediaList);
+    auto lastCommitIsCall = [&](const auto& data) {
+        return !data.messages.empty()
+               && data.messages.rbegin()->type == "application/call-history+json";
+    };
+    // should get message
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return lastCommitIsCall(aliceData_) && lastCommitIsCall(bobData_) && !pInfos_.empty();
+    }));
+    auto confId = bobData_.messages.rbegin()->body.at("confId");
+
+    // Mute host
+    auto call = std::dynamic_pointer_cast<SIPCall>(aliceAccount->getCall(callId));
+    auto proposedList = call->currentMediaList();
+    for (auto& media : proposedList)
+        if (media["LABEL"] == "audio_0")
+            media["MUTED"] = "true";
+    libjami::requestMediaChange(aliceId, confId, proposedList);
+
+    // Bob join, alice must stay muted
+    auto destination = fmt::format("rdv:{}/{}/{}/{}",
+                                   bobData_.id,
+                                   bobData_.messages.rbegin()->body.at("uri"),
+                                   bobData_.messages.rbegin()->body.at("device"),
+                                   confId);
+
+    aliceData_.conferenceChanged = false;
+    pInfos_.clear();
+    auto bobCall = libjami::placeCallWithMedia(bobId, destination, mediaList);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 30s, [&]() {
+        return aliceData_.conferenceChanged && bobData_.hostState == "CURRENT"  && bobData_.state == "CURRENT" && pInfos_.size() == 2;
+    }));
+    // Audio of the host is still muted
+    CPPUNIT_ASSERT(pInfos_[0]["audioLocalMuted"] == "true");
+
+}
+
 } // namespace test
 } // namespace jami
 
