@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
  *
@@ -22,11 +22,10 @@
 #include <cppunit/TestFixture.h>
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "audio/audio_frame_resizer.h"
-#include "audio/audiobuffer.h"
+#include "media/audio/audio_frame_resizer.h"
 #include "jami.h"
-#include "libav_deps.h"
-#include "media_buffer.h"
+#include "media/libav_deps.h"
+#include "media/media_buffer.h"
 
 #include "../../../test_runner.h"
 
