@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2022-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2022-2024 Savoir-faire Linux Inc.
  *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -131,6 +131,7 @@ private:
     void testEnable();
     void testCertificateVerification();
     void testSignatureVerification();
+    void testLoad();
     void testInstallAndLoad();
     void testHandlers();
     void testDetailsAndPreferences();
@@ -142,6 +143,7 @@ private:
     CPPUNIT_TEST(testEnable);
     CPPUNIT_TEST(testCertificateVerification);
     CPPUNIT_TEST(testSignatureVerification);
+    CPPUNIT_TEST(testLoad);
     CPPUNIT_TEST(testInstallAndLoad);
     CPPUNIT_TEST(testHandlers);
     CPPUNIT_TEST(testDetailsAndPreferences);
@@ -349,6 +351,18 @@ PluginsTest::testCertificateVerification()
     CPPUNIT_ASSERT(!Manager::instance().getJamiPluginManager().checkPluginCertificate(pluginNotSignByIssuer_, false));
 }
 
+void
+PluginsTest::testLoad()
+{
+    Manager::instance().pluginPreferences.setPluginsEnabled(true);
+    auto loadedPlugins = Manager::instance().getJamiPluginManager().getLoadedPlugins();
+    CPPUNIT_ASSERT(loadedPlugins.empty());
+    Manager::instance().getJamiPluginManager().installPlugin(jplPath_, true);
+    Manager::instance().getJamiPluginManager().loadPlugins();
+    loadedPlugins = Manager::instance().getJamiPluginManager().getLoadedPlugins();
+    CPPUNIT_ASSERT(!loadedPlugins.empty());
+}
+
 void
 PluginsTest::testInstallAndLoad()
 {
