@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2021-2024 Savoir-faire Linux Inc.
  * Author: Mingrui Zhang   <mingrui.zhang@savoirfairelinux.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 
 #include "accountlistmodel.h"
 #include "deviceitemlistmodel.h"
+#include "moderatorlistmodel.h"
 #include "systemtray.h"
 #include "lrcinstance.h"
 #include "utils.h"
@@ -102,5 +103,6 @@ private:
 
     QScopedPointer<AccountListModel> accountListModel_;
     QScopedPointer<DeviceItemListModel> deviceItemListModel_;
+    QScopedPointer<ModeratorListModel> moderatorListModel_;
 };
 Q_DECLARE_METATYPE(AccountAdapter*)
