@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
  * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
  * Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
  * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
@@ -25,6 +25,10 @@
 #include "screensaver.h"
 #include "calloverlaymodel.h"
 
+#ifdef HAVE_GLOBAL_PTT
+#include "pttlistener.h"
+#endif
+
 #include <QObject>
 #include <QString>
 #include <QVariant>
@@ -33,6 +37,7 @@
 #include "callInformationListModel.h"
 
 class SystemTray;
+class AppSettingsManager;
 
 class CallAdapter final : public QmlAdapterBase
 {
@@ -45,8 +50,11 @@ public:
     enum MuteStates { UNMUTED, LOCAL_MUTED, MODERATOR_MUTED, BOTH_MUTED };
     Q_ENUM(MuteStates)
 
-    explicit CallAdapter(SystemTray* systemTray, LRCInstance* instance, QObject* parent = nullptr);
-    ~CallAdapter() = default;
+    explicit CallAdapter(AppSettingsManager* settingsManager,
+                         SystemTray* systemTray,
+                         LRCInstance* instance,
+                         QObject* parent = nullptr);
+    ~CallAdapter();
 
 public:
     Q_INVOKABLE void startTimerInformation();
@@ -76,6 +84,9 @@ public:
     Q_INVOKABLE void holdThisCallToggle();
     Q_INVOKABLE void recordThisCallToggle();
     Q_INVOKABLE void muteAudioToggle();
+    Q_INVOKABLE bool isMuted(const QString& callId);
+    Q_INVOKABLE void connectPtt();
+    Q_INVOKABLE void disconnectPtt();
     Q_INVOKABLE void muteCameraToggle();
     Q_INVOKABLE bool isRecordingThisCall();
     Q_INVOKABLE void muteParticipant(const QString& accountUri,
@@ -109,6 +120,7 @@ public Q_SLOTS:
     void onCallAddedToConference(const QString& callId, const QString& confId);
     void onCallStarted(const QString& callId);
     void onCallEnded(const QString& callId);
+    void onCallInfosChanged(const QString& accountId, const QString& callId);
 
 private:
     void showNotification(const QString& accountId, const QString& convUid);
@@ -121,6 +133,9 @@ private:
     SystemTray* systemTray_;
     QScopedPointer<CallOverlayModel> overlayModel_;
     VectorString currentConfSubcalls_;
-
     std::unique_ptr<CallInformationListModel> callInformationListModel_;
+
+    PTTListener* listener_;
+    bool isMicrophoneMuted_ = true;
+    QSet<QString> toMute;
 };
