@@ -1,5 +1,5 @@
 /*!
- * Copyright (C) 2015-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2015-2024 Savoir-faire Linux Inc.
  * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
  * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
  * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
@@ -48,7 +48,6 @@
 #endif
 
 #include "api/account.h"
-#include "api/contact.h"
 #include "api/contactmodel.h"
 #include "api/conversationmodel.h"
 
@@ -119,12 +118,11 @@ QPixmap generateTintedPixmap(const QPixmap& pix, QColor color);
 QImage scaleAndFrame(const QImage photo, const QSize& size = defaultAvatarSize);
 QImage cropImage(const QImage& img);
 QPixmap pixmapFromSvg(const QString& svg_resource, const QSize& size);
-QImage setupQRCode(QString ringID, int margin);
+QImage getQRCodeImage(QString data, int margin);
 bool isImage(const QString& fileExt);
 QString generateUid();
 
 // Misc
 QString humanFileSize(qint64 fileSize);
 QString getDebugFilePath();
-
 } // namespace Utils
