@@ -1,5 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2023 Savoir-faire Linux Inc.                       *
+ *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
  *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
  *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
  *   Author: Kateryna Kostiuk <kateryna.kostiuk@savoirfairelinux.com>       *
@@ -49,6 +49,7 @@
 #include <QtGui/QPixmap>
 #include <QtGui/QImage>
 #include <QtCore/QBuffer>
+#include <QJsonDocument>
 
 #include <atomic>
 
@@ -320,7 +321,7 @@ AccountModel::registerName(const QString& accountId,
                            const QString& password,
                            const QString& username)
 {
-    return ConfigurationManager::instance().registerName(accountId, password, username);
+    return ConfigurationManager::instance().registerName(accountId, username, "password", password);
 }
 
 bool
@@ -328,7 +329,7 @@ AccountModel::exportToFile(const QString& accountId,
                            const QString& path,
                            const QString& password) const
 {
-    return ConfigurationManager::instance().exportToFile(accountId, path, password);
+    return ConfigurationManager::instance().exportToFile(accountId, path, "password", password);
 }
 
 bool
@@ -563,8 +564,8 @@ AccountModelPimpl::slotAccountDetailsChanged(const QString& accountId,
 {
     auto account = accounts.find(accountId);
     if (account == accounts.end()) {
-        throw std::out_of_range("AccountModelPimpl::slotAccountDetailsChanged, can't find "
-                                + accountId.toStdString());
+        qWarning() << Q_FUNC_INFO << ": can't find " << accountId;
+        return;
     }
     auto& accountInfo = account->second.first;
     accountInfo.fromDetails(details);
@@ -584,8 +585,7 @@ AccountModelPimpl::slotVolatileAccountDetailsChanged(const QString& accountId,
 {
     auto account = accounts.find(accountId);
     if (account == accounts.end()) {
-        qWarning() << "AccountModelPimpl::slotVolatileAccountDetailsChanged, can't find "
-                   << accountId;
+        qWarning() << Q_FUNC_INFO << ": can't find " << accountId;
         return;
     }
     auto& accountInfo = account->second.first;
@@ -901,7 +901,6 @@ account::Info::fromDetails(const MapStringString& details)
                                           ? account::KeyExchangeProtocol::NONE
                                           : account::KeyExchangeProtocol::SDES;
     confProperties.SRTP.enable = toBool(details[ConfProperties::SRTP::ENABLED]);
-    confProperties.SRTP.rtpFallback = toBool(details[ConfProperties::SRTP::RTP_FALLBACK]);
     // TLS
     confProperties.TLS.listenerPort = toInt(details[ConfProperties::TLS::LISTENER_PORT]);
     confProperties.TLS.enable = details[ConfProperties::TYPE] == QString(ProtocolNames::RING)
@@ -928,6 +927,11 @@ account::Info::fromDetails(const MapStringString& details)
     // Jams
     confProperties.managerUri = details[ConfProperties::MANAGER_URI];
     confProperties.managerUsername = details[ConfProperties::MANAGER_USERNAME];
+    // uiCustomization
+    QJsonDocument doc = QJsonDocument::fromJson(details[ConfProperties::UI_CUSTOMIZATION].toUtf8());
+    if (!doc.isNull() && doc.isObject()) {
+        confProperties.uiCustomization = doc.object();
+    }
 }
 
 MapStringString
@@ -1008,7 +1012,6 @@ account::ConfProperties_t::toDetails() const
                                                       ? ""
                                                       : "sdes";
     details[ConfProperties::SRTP::ENABLED] = toQString(this->SRTP.enable);
-    details[ConfProperties::SRTP::RTP_FALLBACK] = toQString(this->SRTP.rtpFallback);
     // TLS
     details[ConfProperties::TLS::LISTENER_PORT] = toQString(this->TLS.listenerPort);
     details[ConfProperties::TLS::ENABLED] = toQString(this->TLS.enable);
@@ -1033,6 +1036,9 @@ account::ConfProperties_t::toDetails() const
     // Manager
     details[ConfProperties::MANAGER_URI] = this->managerUri;
     details[ConfProperties::MANAGER_USERNAME] = this->managerUsername;
+    // UI Customization
+    QJsonDocument doc(this->uiCustomization);
+    details[ConfProperties::UI_CUSTOMIZATION] = doc.toJson(QJsonDocument::Compact);
 
     return details;
 }
@@ -1198,6 +1204,14 @@ AccountModel::notificationsCount() const
     return total;
 }
 
+void
+AccountModel::reloadHistory()
+{
+    for (const auto& [_id, account] : pimpl_->accounts) {
+        account.first.conversationModel->reloadHistory();
+    }
+}
+
 QString
 AccountModel::avatar(const QString& accountId) const
 {
